@@ -3,8 +3,8 @@ from dataclasses import dataclass
 from functools import total_ordering
 from typing import Optional, Type
 
-MarshallerContext = 'marshy.marshaller_context.MarshallerContext'
-MarshallerABC = 'marshy.marshaller_abc.MarshallerABC'
+_MarshallerContext = 'marshy.marshaller_context.MarshallerContext'
+_MarshallerABC = 'marshy.marshaller_abc.MarshallerABC'
 
 
 @dataclass
@@ -20,8 +20,8 @@ class MarshallerFactoryABC(ABC):
 
     @abstractmethod
     def create(self,
-               context: MarshallerContext,
-               type_: Type) -> Optional[MarshallerABC]:
+               context: _MarshallerContext,
+               type_: Type) -> Optional[_MarshallerABC]:
         """
         Create a new marshaller instance if possible - if not return None
         """
