@@ -1,19 +1,19 @@
 import importlib
-from typing import Type, List, Dict
+import typing
 
 import typing_inspect
 
 from marshy.errors import MarshallError
 
+_TYPES_BY_ORIGIN = {t.__origin__: t for t in typing.__dict__.values() if hasattr(t, '__origin__')}
 
-def resolve_forward_refs(type_: Type) -> Type:
+
+def resolve_forward_refs(type_: typing.Type) -> typing.Type:
     origin = typing_inspect.get_origin(type_)
-    if origin:
+    if origin is not None:
         args = list(resolve_forward_refs(a) for a in typing_inspect.get_args(type_))
-        if origin is list:
-            origin = List
-        elif origin is dict:
-            origin = Dict
+        typing_origin = _TYPES_BY_ORIGIN.get(origin)
+        origin = typing_origin or origin
         return origin[tuple(args)]
     if not typing_inspect.is_forward_ref(type_):
         return type_
